.. ..  index.rst -*- mode: ReST -*-

.. _index:

================================
dootle: The Documentation
================================


.. contents:: Contents

.. _intro:

Introduction
------------

Testing one  two three.
Lorem ipsum dolor sit amet, consectetuer adipiscing elit.  Donec hendrerit
tempor tellus.  Donec pretium posuere tellus.  Proin quam nisl, tincidunt et,
mattis eget, convallis nec, purus.  Cum sociis natoque penatibus et magnis dis
parturient montes, nascetur ridiculus mus.  Nulla posuere.  Donec vitae dolor.
Nullam tristique diam non turpis.  Cras placerat accumsan nulla.  Nullam rutrum.
Nam vestibulum accumsan nisl.


Overview
--------

Pellentesque dapibus suscipit ligula.  Donec posuere augue in quam.  Etiam vel
tortor sodales tellus ultricies commodo.  Suspendisse potenti.  Aenean in sem ac
leo mollis blandit.  Donec neque quam, dignissim in, mollis nec, sagittis eu,
wisi.  Phasellus lacus.  Etiam laoreet quam sed arcu.  Phasellus at dui in
ligula mollis ultricies.  Integer placerat tristique nisl.  Praesent augue.
Fusce commodo.  Vestibulum convallis, lorem a tempus semper, dui dui euismod
elit, vitae placerat urna tortor vitae lacus.  Nullam libero mauris, consequat
quis, varius et, dictum id, arcu.  Mauris mollis tincidunt felis.  Aliquam
feugiat tellus ut neque.  Nulla facilisis, risus a rhoncus fermentum, tellus
tellus lacinia purus, et dictum nunc justo sit amet elit.



Repo and Issues
---------------

The repo for doot can be found `here <https://github.com/jgrey4296/dootle>`_.

If you find a bug, bug me, unsurprisingly, on the `issue tracker <https://github.com/jgrey4296/dootle/issues>`_.


.. .. Main Sidebar Toctree
.. toctree::
   :maxdepth: 3
   :glob:
   :hidden:

   [a-z]*/index
   
   __docs/getting_started
   __docs/examples/overview
   __docs/architecture/overview
   FAQ <__docs/faq>

   genindex
   modindex
   API Reference <autoapi/dootle/index>


.. .. Links
